@@ -68,6 +68,9 @@ class NavigatorView(View):
             for default_button in default_buttons:
                 self.add_item(default_button)
 
+        if not pages:
+            raise ValueError(f"Expected at least one page to be passed to {type(self).__name__}.")
+
     @property
     def pages(self) -> t.Sequence[t.Union[str, hikari.Embed]]:
         """
@@ -202,6 +205,27 @@ class NavigatorView(View):
 
         await context.edit_response(**payload, attachment=None)
 
+    async def swap_pages(
+        self, context: Context[t.Any], new_pages: t.Sequence[t.Union[str, hikari.Embed]], start_at: int = 0
+    ) -> None:
+        """Swap out the pages of the navigator to the newly provided pages.
+        By default, the navigator will reset to the first page.
+
+        Parameters
+        ----------
+        context : Context
+            The context object that should be used to send the updated pages
+        new_pages : Sequence[Union[str, Embed]]
+            The new pages to swap to
+        start_at : int, optional
+            The page to start at, by default 0
+        """
+        if not new_pages:
+            raise ValueError(f"Expected at least one page to be passed to {type(self).__name__}.")
+
+        self._pages = new_pages
+        await self.send_page(context, page_index=start_at)
+
     async def start(
         self,
         message: t.Optional[
@@ -256,7 +280,7 @@ class NavigatorView(View):
 
         if self.ephemeral and self.timeout and self.timeout > 900:
             logger.warning(
-                f"Using a timeout value longer than 900 seconds (Used {self.timeout}) in ephemeral navigator {self.__class__.__name__} may cause on_timeout to fail."
+                f"Using a timeout value longer than 900 seconds (Used {self.timeout}) in ephemeral navigator {type(self).__name__} may cause on_timeout to fail."
             )
 
         payload = self._get_page_payload(self.pages[start_at])
