@@ -55,24 +55,15 @@ class TextInput(ModalItem):
         custom_id: t.Optional[str] = None,
         row: t.Optional[int] = None,
     ) -> None:
-        super().__init__(custom_id, required)
+        super().__init__(custom_id=custom_id, row=row, required=required)
         self._width: int = 5
-        self._style: t.Union[hikari.TextInputStyle, int] = style
-        self._placeholder: t.Optional[str] = str(placeholder) if placeholder else None
+        # Set value directly to avoid validation with missing values
         self._value: t.Optional[str] = str(value) if value else None
-        self._label: str = str(label)
-        self._max_length: t.Optional[int] = max_length
-        self._min_length: t.Optional[int] = min_length
-        self._row: t.Optional[int] = int(row) if row is not None else None
-
-        if not self._value:
-            return
-
-        if self.min_length is not None and self.min_length > len(self._value):
-            raise ValueError("Parameter value does not meet minimum length requirement.")
-
-        if self.max_length is not None and self.max_length < len(self._value):
-            raise ValueError("Parameter value does not meet maximum length requirement.")
+        self.style = style
+        self.placeholder = placeholder
+        self.label = label
+        self.max_length = max_length
+        self.min_length = min_length
 
     @property
     def type(self) -> hikari.ComponentType:
@@ -101,6 +92,8 @@ class TextInput(ModalItem):
 
     @label.setter
     def label(self, value: str) -> None:
+        if len(value) > 45:
+            raise ValueError(f"Parameter 'label' must be 45 or fewer in length. (Found length {len(value)})")
         self._label = str(value)
 
     @property
@@ -112,6 +105,8 @@ class TextInput(ModalItem):
 
     @placeholder.setter
     def placeholder(self, value: t.Optional[str]) -> None:
+        if value is not None and len(value) > 100:
+            raise ValueError(f"Parameter 'placeholder' must be 100 or fewer in length. (Found length {len(value)})")
         self._placeholder = str(value) if value else None
 
     @property
@@ -140,7 +135,7 @@ class TextInput(ModalItem):
 
     @min_length.setter
     def min_length(self, value: t.Optional[int]) -> None:
-        if not isinstance(value, int):
+        if value and not isinstance(value, int):
             raise TypeError("Expected type int for property min_length.")
         if self.value:
             if value is not None and value > len(self.value):
@@ -154,7 +149,7 @@ class TextInput(ModalItem):
 
     @max_length.setter
     def max_length(self, value: t.Optional[int]) -> None:
-        if not isinstance(value, int):
+        if value and not isinstance(value, int):
             raise TypeError("Expected type int for property max_length.")
         if self.value:
             if value is not None and value < len(self.value):
