@@ -20,7 +20,11 @@ from .abc.item import ViewItem
 from .abc.item_handler import ItemHandler
 from .button import Button
 from .context.view import ViewContext
-from .select import Select
+from .select import ChannelSelect
+from .select import MentionableSelect
+from .select import RoleSelect
+from .select import TextSelect
+from .select import UserSelect
 
 logger = logging.getLogger(__name__)
 
@@ -29,6 +33,16 @@ __all__ = (
     "get_view",
 )
 
+COMPONENT_VIEW_ITEM_MAPPING: t.Mapping[hikari.ComponentType, t.Type[ViewItem]] = {
+    hikari.ComponentType.BUTTON: Button,
+    hikari.ComponentType.TEXT_SELECT_MENU: TextSelect,
+    hikari.ComponentType.CHANNEL_SELECT_MENU: ChannelSelect,
+    hikari.ComponentType.ROLE_SELECT_MENU: RoleSelect,
+    hikari.ComponentType.USER_SELECT_MENU: UserSelect,
+    hikari.ComponentType.MENTIONABLE_SELECT_MENU: MentionableSelect,
+}
+"""A mapping of all message component types to their respective item classes."""
+
 
 class View(ItemHandler[hikari.impl.MessageActionRowBuilder]):
     """Represents a set of Discord UI components attached to a message.
@@ -169,11 +183,10 @@ class View(ItemHandler[hikari.impl.MessageActionRowBuilder]):
             assert isinstance(action_row, hikari.ActionRowComponent)
 
             for component in action_row.components:
-                if isinstance(component, hikari.ButtonComponent):
-                    view.add_item(Button._from_component(component, row))
-
-                elif isinstance(component, hikari.SelectMenuComponent):
-                    view.add_item(Select._from_component(component, row))
+                if not isinstance(component.type, hikari.ComponentType):
+                    continue  # Unrecognized component types are ignored
+                comp_cls = COMPONENT_VIEW_ITEM_MAPPING[component.type]
+                view.add_item(comp_cls._from_component(component, row))
 
         return view
 
@@ -357,19 +370,15 @@ class View(ItemHandler[hikari.impl.MessageActionRowBuilder]):
             miru.install() was not called before starting a view.
         """
         if self._events is None:
-            raise BootstrapFailureError(
-                f"Cannot start View {self.__class__.__name__} before calling miru.install() first."
-            )
+            raise BootstrapFailureError(f"Cannot start View {type(self).__name__} before calling miru.install() first.")
 
         # Optimize URL-button-only views by not adding to listener
         if all((isinstance(item, Button) and item.url is not None) for item in self.children):
-            logger.warning(f"View {self.__class__.__name__} only contains link buttons. Ignoring 'View.start()' call.")
+            logger.warning(f"View {type(self).__name__} only contains link buttons. Ignoring 'View.start()' call.")
             return
 
         if message is None and not self.is_persistent:
-            raise ValueError(
-                f"View '{self.__class__.__name__}' is not persistent, parameter 'message' must be provided."
-            )
+            raise ValueError(f"View '{type(self).__name__}' is not persistent, parameter 'message' must be provided.")
 
         if message is None:
             self._events.add_handler(self)
